@@ -168,17 +168,17 @@ class ClassCodeConfig():
         {
             "ClassCode": "1007",
             "ClassName": "历史行情",
-            "TargetUnitCode": {'1007001': '数据集合', '1007002': '最高价', '1007003': '成交额', '1007004': '开盘价', '1007005': '最低价',
-                 '1007006': '换手率', '1007007': '振幅', '1007008': '涨跌幅', '1007009': '收盘价', '1007010': '日期',
-                 '1007011': '成交量', '1007012': '股票简称', '1007013': '股票代码', '1007014': '复权类型', '1007015': '市场类型',
-                 '1007016': '是否指数数据'}
+            "TargetUnitCode": {'1007001': 'data', '1007002': 'high', '1007003': 'vol2', '1007004': 'open', '1007005': 'low',
+                 '1007006': 'turnover', '1007007': 'Amplitude', '1007008': 'p_change', '1007009': 'close', '1007010': 'date',
+                 '1007011': 'volume', '1007012': 'name', '1007013': 'code', '1007014': 'fqt', '1007015': 'type',
+                 '1007016': 'is_dapan'}
         }
         ,
         {
             "ClassCode": "1008",
             "ClassName": "五分钟数据",
-            "TargetUnitCode": {'1008004': '最高价', '1008007': '成交额', '1008002': '开盘价', '1008005': '最低价', '1008008': '换手率'
-                , '1008009': '振幅', '1008010': '涨跌幅', '1008003': '收盘价', '1008001': '时间', '1008006': '成交量'}
+            "TargetUnitCode": {'1008004': 'high', '1008007': 'vol2', '1008002': 'open', '1008005': 'low', '1008008': 'turnover'
+                , '1008009': 'Amplitude', '1008010': 'p_change', '1008003': 'close', '1008001': 'date', '1008006': 'volume'}
         }
     ]
 
@@ -425,7 +425,7 @@ class DataSource(BaseFunc):
         except IOError as e:
             raise Exception("目标文件夹没有该文件,可能是参数传递错误,路径为："+path)
 
-class MianClass():
+class MainClass():
     def __init__(self, RootPath,PoolSize = 3):
         self.PoolSize = PoolSize
         self.RootPath = os.path.join(RootPath,"System")
@@ -455,7 +455,7 @@ class MianClass():
         '''
         获取资源路径
         :param data_type: [INDEX,SH,SZ]
-        :param ktype: [day,fzline,finance]
+        :param ktype: [day,5,finance]
         :param fqt:
         :return:
         '''
@@ -474,18 +474,18 @@ class MianClass():
         data_path_dict = {
             "INDEX":{
                 "path":"INDEX",
-                "day":day_path,
+                "D":day_path,
                 "5":fzline_path
             },
             "SH":{
                 "path": "SH",
-                "day":day_path,
+                "D":day_path,
                 "5":fzline_path,
                 "finance":finance_path
             },
             "SZ":{
                 "path": "SZ",
-                "day":day_path,
+                "D":day_path,
                 "5":fzline_path,
                 "finance":finance_path
             }
@@ -495,7 +495,7 @@ class MianClass():
         path_3 = path_2["suffix"]
         return os.path.join(self.RootPath,path_1["path"],path_2["path"],code+'.'+path_3[fqt])
 
-    def get_k_data(self,code,start,end='',fqt="0",ktype='day'):
+    def get_k_data(self,code,start,end='',fqt="0",ktype='D'):
         '''行情数据'''
         data_type = self._get_market(code)
         file_path = self._get_data_path(data_type,ktype,fqt,code)
@@ -537,7 +537,7 @@ class MianClass():
         file_path = self._get_data_path(data_type, "finance", "0", code)
         return self._do_something_data(file_path, start, end, "1003")
 
-    def get_Index_data(self, code,start,end='',fqt="0",ktype='day'):
+    def get_Index_data(self, code,start,end='',fqt="0",ktype='D'):
         '''
         指数数据
         :param code:
@@ -548,23 +548,22 @@ class MianClass():
         file_path = self._get_data_path("INDEX", ktype, fqt, code)
         return self._do_something_data(file_path, start, end)
 
-    def get_stockIndex_data(self,code,base_code,start,end='',fqt="0",ktype='day',bFillNA=False):
+    def get_stockIndex_data(self,code,base_code,start,end='',fqt="0",ktype='D',bFillNA=False):
         k_data = self.get_k_data(code,start,end,fqt,ktype)
         index_data = self.get_Index_data(base_code,start,end,fqt,ktype)
-        base_stock_data = index_data.loc[:, ['日期', '收盘价']]
-        base_stock_data.rename(columns={'收盘价': '指数收盘价'}, inplace=True)
+        base_stock_data = index_data.loc[:, ['date', 'close']]
+        base_stock_data.rename(columns={'close': 'base_close'}, inplace=True)
 
-        result = pd.concat([k_data.set_index('日期'), base_stock_data.set_index('日期')], axis=1).reset_index()
+        result = pd.concat([k_data.set_index('date'), base_stock_data.set_index('date')], axis=1).reset_index()
 
         if (bFillNA):
             result = result.fillna(axis=0, method='ffill')
 
         result = result.dropna(axis=0, how='any')
         result.reset_index(drop=True, inplace=True)
-        result.rename(columns={'index': '日期'}, inplace=True)
+        result.rename(columns={'index': 'date'}, inplace=True)
         if (len(result) <= 0):
             return pd.DataFrame()
-
         return result
 
 if __name__ == '__main__':
@@ -572,7 +571,7 @@ if __name__ == '__main__':
     #              "000010.sz","000011.sz","000012.sz","000014.sz","000016.sz","000017.sz","000018.sz","000019.sz",
     #              "000020.sz","000021.sz","000023.sz","000024.sz","000025.sz","000026.sz","000027.sz","000028.sz"]
     code_list = ["000001"]
-    mainclass= MianClass(r"D:\tby_svn\wta_finance\trunk\2 项目实施阶段\2.4 系统开发\2.4.1 系统实现\WtaFinancePlatform\WtaFinancePlatform_WPF\bin\x86\Debug\Data")
+    mainclass= MainClass(r"D:\tby_svn\wta_finance\trunk\2 项目实施阶段\2.4 系统开发\2.4.1 系统实现\WtaFinancePlatform\WtaFinancePlatform_WPF\bin\x86\Debug\Data")
     System = {
         "classList":"*"
         #     [
